#!/usr/bin/env python

import sys
import os.path
from PyQt5.QtWidgets import (QApplication, QWidget, QComboBox, QVBoxLayout, QTreeView, \
    QFileSystemModel, QFileIconProvider)
from PyQt5.QtGui import QIcon
from PyQt5.QtCore import (Qt, QDir)

HOMEPATH = QDir.homePath()
USERSHARE = os.path.join(HOMEPATH, '.test/share')
CBOX_LIST = (
    ('Home', HOMEPATH),
    ('UserShare', USERSHARE)
)

class NoIcons(QFileIconProvider):
    def icon(self, int):
        return QIcon()

class Form(QWidget):

    def __init__(self, parent=None):
        super().__init__(parent)
        self.setAttribute(Qt.WA_DeleteOnClose)
        self.createWidgets()
        self.createLayout()
        self.createComLinks()
        return

    def createWidgets(self):
        if not os.path.isdir(USERSHARE):
            os.makedirs(USERSHARE)
        self.cbox = QComboBox()
        for data in CBOX_LIST:
            self.cbox.addItem(data[0], data[1])
        self.tree = QTreeView()
        self.model = QFileSystemModel()
        self.model.setFilter(QDir.AllDirs | QDir.NoDotAndDotDot)
        self.model.setIconProvider(NoIcons())
        self.tree.setModel(self.model)
        self.tree.setHeaderHidden(True)
        for col in range(1, 4):
            self.tree.hideColumn(col)
        self.setRootPath(CBOX_LIST[0][1])
        return

    def createLayout(self):
        layout = QVBoxLayout()
        layout.addWidget(self.cbox)
        layout.addWidget(self.tree)
        self.setLayout(layout)
        return

    def createComLinks(self):
        self.cbox.currentIndexChanged.connect(\
            lambda: self.setRootPath(self.cbox.currentData()))
        return

    def setRootPath(self, path):
        self.model.setRootPath(path)
        rootIndex = self.model.index(path)
        if rootIndex.isValid():
            self.tree.setRootIndex(rootIndex)
        return

if __name__ == '__main__':
    app = QApplication(sys.argv)
    form = Form()
    form.show()
    app.exec_()

